# My - Data

This repository contains the code to work with the database of the __My Project__. This library uses the [My model](https://github.com/DarylStark/my_model) package to define the database models. It uses SQLModel to talk to the database. This package is published on PyPI as `ds-my-data` to prevent name clashes with other packages.

## Installing

Installing this Python library can be done with the regular `pip` tooling:

```bash
pip install ds-my-data
```

After installing, you can use it. In the documentation on GitHub page is explained how to use it.

## Developing

If you want to develop on this library, you can create your own development environment, or use the DevContainer provided in this repository. To use the provided DevContainer, all you have to do is open this repository in VScode and select `Open in Dev Container` in the command palette. You need to have the `Dev Containers` extension installed for this and you need Docker or PodMan to run the container.